%define major 1
%define libname %mklibname user %{major}
%define devname %mklibname user -d

%bcond_with check
%{?build_selinux}%{?!build_selinux:%bcond_with selinux}

Summary:	A user and group account administration library
Name:		libuser
Version:	0.62
Release:	1
License:	LGPLv2.1+
Group:		System/Configuration/Other
Url:		https://fedorahosted.org/libuser/
Source0:	https://fedorahosted.org/releases/l/i/libuser/%{name}-%{version}.tar.xz
# patches merged upstream (to be drop on next update):
Patch0:		libuser-0.56.9-fix-str-fmt.patch
# default to blowfish for passwords instead of md5 (#59158)
Patch3:		libuser-0.57.1-borkfix.diff
BuildRequires:	bison
BuildRequires:	gettext
BuildRequires:	linuxdoc-tools
# To make sure the configure script can find it
BuildRequires:	nscd
BuildRequires:	openldap-devel
BuildRequires:	pam-devel
%if %{with selinux}
BuildRequires:	selinux-devel
%endif
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(popt)
BuildRequires:	pkgconfig(python)
%if %{with check}
# For %%check
BuildRequires:	openldap-servers openldap-clients
%endif

%description
The libuser library implements a standardized interface for manipulating
and administering user and group accounts.  The library uses pluggable
back-ends to interface to its data sources.

Sample applications modeled after those included with the shadow password
suite are included.

%files -f %{name}.lang
%doc AUTHORS NEWS README TODO docs/*.txt python/modules.txt
%config(noreplace) %{_sysconfdir}/libuser.conf
%{_bindir}/*
%{_sbindir}/*
%dir %{_libdir}/%{name}/
%{_libdir}/%{name}/libuser_files.so
%{_libdir}/%{name}/libuser_shadow.so
%{_mandir}/man5/*
%{_mandir}/man1/*

#----------------------------------------------------------------------------

%package ldap
Summary:	Libuser LDAP library
Group:		System/Libraries

%description ldap
This package contains the libuser LDAP library.

%files ldap
%{_libdir}/%{name}/libuser_ldap.so

#----------------------------------------------------------------------------

%package -n %{libname}
Summary:	The actual libraries for libuser
Group:		System/Libraries

%description -n %{libname}
This is the actual library for the libuser library.

%files -n %{libname}
%{_libdir}/libuser.so.%{major}*

#----------------------------------------------------------------------------

%package -n %{devname}
Summary:	Files needed for developing applications which use libuser
Group:		Development/C
Requires:	%{libname} = %{EVRD}
Provides:	%{name}-devel = %{EVRD}

%description -n %{devname}
The libuser-devel package contains header files, static libraries, and other
files useful for developing applications with libuser.

%files -n %{devname}
%dir %{_includedir}/libuser
%{_includedir}/libuser/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*
%{_datadir}/gtk-doc/html/*

#----------------------------------------------------------------------------

%package python
Summary:	Library bindings for python
Group:		Development/Python

%description python
This package contains the python library for python applications that 
use libuser.

%files python
%{py_platsitedir}/*.so

#----------------------------------------------------------------------------

%prep
%setup -q
%patch0 -p0
%patch3 -p0

# fix tha tests
perl -pi -e "s|/etc/openldap/schema|/usr/share/openldap/schema|g" tests/slapd.conf.in

%build
export CFLAGS="%{optflags} -fPIC -DG_DISABLE_ASSERT -I/usr/include/sasl -DLDAP_DEPRECATED"
%configure2_5x \
	--with-ldap \
	--with-python \
	--with-popt \
	--without-sasl \
	--disable-rpath \
%if %{with selinux}
	--with-selinux \
%else
	--without-selinux \
%endif
	--enable-gtk-doc=no
%make

%install
%makeinstall_std

%find_lang %{name}

# Remove unpackaged files
rm -rf  %{buildroot}/usr/share/man/man3/userquota.3 \
        %{buildroot}%{py_platsitedir}/*a \
        %{buildroot}%{_libdir}/%{name}/*.la \
        %{buildroot}%{_libdir}/*.la

LD_LIBRARY_PATH=%{buildroot}%{_libdir}:${LD_LIBRARY_PATH}
export LD_LIBRARY_PATH

# Verify that all python modules load, just in case.
pushd %{buildroot}/%{_libdir}/python%{py_ver}/site-packages/
    python -c "import libuser"
popd

%if %{with check}
%check
# note: the tests uses fixed ports 3890 and 6360
#LD_LIBRARY_PATH=%{buildroot}%{_libdir}:${LD_LIBRARY_PATH}
#export LD_LIBRARY_PATH
make check
%endif

%changelog

* Thu May 12 2016 abondrov <andrey.bondrov@rosalab.ru> 0.62-1
- (9230e01) Merge pull request #1 from alzim/libuser:rosa2014.1
- (9230e01) Updated to 0.62


